Skip to main content
summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorbvosburgh2011-03-09 18:34:23 +0000
committerbvosburgh2011-03-09 18:34:23 +0000
commit2f66985cecaf086dce30b9cf5c204e5af052476e (patch)
treee58272b4cb19162d6175a6e36f16ecd38a5a77a2 /jpa/plugins/org.eclipse.jpt.jpa.eclipselink.ui/src
parenteda5b6915e0dfb7ebab3d2cc34ab7581aaecd9fa (diff)
downloadwebtools.dali-2f66985cecaf086dce30b9cf5c204e5af052476e.tar.gz
webtools.dali-2f66985cecaf086dce30b9cf5c204e5af052476e.tar.xz
webtools.dali-2f66985cecaf086dce30b9cf5c204e5af052476e.zip
[335343] fix combo box behavior - patch from Nan
Diffstat (limited to 'jpa/plugins/org.eclipse.jpt.jpa.eclipselink.ui/src')
-rw-r--r--jpa/plugins/org.eclipse.jpt.jpa.eclipselink.ui/src/org/eclipse/jpt/jpa/eclipselink/ui/internal/details/EclipseLinkConvertComposite.java11
1 files changed, 8 insertions, 3 deletions
diff --git a/jpa/plugins/org.eclipse.jpt.jpa.eclipselink.ui/src/org/eclipse/jpt/jpa/eclipselink/ui/internal/details/EclipseLinkConvertComposite.java b/jpa/plugins/org.eclipse.jpt.jpa.eclipselink.ui/src/org/eclipse/jpt/jpa/eclipselink/ui/internal/details/EclipseLinkConvertComposite.java
index e861f6579f..c0d90d99be 100644
--- a/jpa/plugins/org.eclipse.jpt.jpa.eclipselink.ui/src/org/eclipse/jpt/jpa/eclipselink/ui/internal/details/EclipseLinkConvertComposite.java
+++ b/jpa/plugins/org.eclipse.jpt.jpa.eclipselink.ui/src/org/eclipse/jpt/jpa/eclipselink/ui/internal/details/EclipseLinkConvertComposite.java
@@ -103,6 +103,7 @@ public class EclipseLinkConvertComposite
buildNoConverterHolder(),
null);
PropertyValueModel<EclipseLinkConverter> converterHolder = buildConverterHolder();
+
// CustomConverter
addRadioButton(
subSection,
@@ -159,14 +160,15 @@ public class EclipseLinkConvertComposite
@Override
protected void setValue_(String value) {
// Convert the default value to an empty string
if ((value != null) && (value.startsWith(DEFAULT_KEY))) {
- value = "";
+ value = EclipseLinkConvert.DEFAULT_CONVERTER_NAME;
}
this.subject.setSpecifiedConverterName(value);
}
};
}
+
private ListValueModel<String> buildConvertNameListHolder() {
java.util.List<ListValueModel<String>> list = new ArrayList<ListValueModel<String>>();
list.add(buildDefaultNameListHolder());
@@ -228,7 +230,10 @@ public class EclipseLinkConvertComposite
);
}
else {
- value = JptCommonUiMessages.DefaultEmpty;
+ value = NLS.bind(
+ JptCommonUiMessages.DefaultWithOneParam,
+ EclipseLinkConvert.NO_CONVERTER
+ );
}
}
@@ -159,14 +160,15 @@ public class EclipseLinkConvertComposite
protected void setValue_(String value) {
- // Convert the default value to an empty string
+ // Convert the default value to the default converter
if ((value != null) && (value.startsWith(DEFAULT_KEY))) {

Back to the top